--[[--------------------------------------------------------------------------------------------------
BackButtonHandler

Version: 		004
Author: 		Torben Ratzlaff
Website: 		screenheadmedia.com

Purpose:
Administrates the Android Back Button
----------------------------------------------------------------------------------------------------]]


--[[--------------------------------------------------------------------------------------------------
How to use:

--starts the BackButtonHandler
BackButtonHandler.start()


--pauses the BackButtonHandler
BackButtonHandler.pause()


--sets a callback for the case the Android back button is pressed
BackButtonHandler.setCallback(callback)
--callback 		- callback function or table with object and function name (e.g. functionA()  or  {object1, "funtionName"})


--set a default alertData for localizing purposes
BackButtonHandler.setDefaultAlert(alertData)
--alertData		- the alerts data table, by default: {title = "Exit -Your Apps Name-", caption = "Do you want do exit -Your Apps Name-?",  buttons = {"Yes", "No"}}

----------------------------------------------------------------------------------------------------]]


local appName = system.getInfo("appName") or "the application"
local native_showAlert = native.showAlert
local type = type


local BackButtonHandler = {}

local defaultAlert = {title = "Exit "..appName, caption = "Do you want do exit "..appName.."?",  buttons = {"Yes", "No"}}

function BackButtonHandler.start()
	if not BackButtonHandler.isActive then
		BackButtonHandler.isActive = true
		Runtime:addEventListener( "key", BackButtonHandler )
	end
end

function BackButtonHandler.pause()
	if BackButtonHandler.isActive then
		BackButtonHandler.isActive = nil
		Runtime:removeEventListener( "key", BackButtonHandler )
	end
end

function BackButtonHandler.setCallback(callback)
	BackButtonHandler.callback = callback
	BackButtonHandler.doCallback = true
end

function BackButtonHandler.setDefaultAlert(alertData)
	assert(alertData, "BackButtonHandler.setDefaultAlert - You have to specify an alert data [table]")
	defaultAlert = alertData
end


function BackButtonHandler:key(event)
	local phase = event.phase
	local keyName = event.keyName
   	
  	if keyName == "back" then
  		if phase == "up" then
	  		local callback = self.callback
	  		
	  		if callback == "exit" then
	  			local function alertListener(event)
	  				 if "clicked" == event.action then
				        local i = event.index
				       	if 1 == i then
				        	native.requestExit()
				        elseif 2 == i then
				        
				        end
				    end
	  			end
	  			
	  			local alertData = self.alertData or defaultAlert
	  		
	  			native_showAlert(alertData.title, alertData.caption, alertData.buttons, alertListener)
	  	
	  		elseif self.doCallback then
	  			self.doCallback = nil
	  			
	  			if callback then
	  				if type(callback) == "function" then
	  					callback()
	  				elseif type(callback) == "table" then
	  					callback[1](callback[2])
	  				end
	  			end
	  		end
  		end
  		
  		return true
  	end
  	
  	return false
end


return BackButtonHandler